@@ -2,24 +2,24 @@
  * Copyright 1990 Network Computing Devices;
  * Portions Copyright 1987 by Digital Equipment Corporation
  *
- * Permission to use, copy, modify, distribute, and sell this software 
- * and its documentation for any purpose is hereby granted without fee, 
- * provided that the above copyright notice appear in all copies and 
- * that both that copyright notice and this permission notice appear 
- * in supporting documentation, and that the names of Network Computing 
- * Devices or Digital not be used in advertising or publicity pertaining 
- * to distribution of the software without specific, written prior 
- * permission. Network Computing Devices or Digital make no representations 
- * about the suitability of this software for any purpose.  It is provided 
+ * Permission to use, copy, modify, distribute, and sell this software
+ * and its documentation for any purpose is hereby granted without fee,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear
+ * in supporting documentation, and that the names of Network Computing
+ * Devices or Digital not be used in advertising or publicity pertaining
+ * to distribution of the software without specific, written prior
+ * permission. Network Computing Devices or Digital make no representations
+ * about the suitability of this software for any purpose.  It is provided
  * "as is" without express or implied warranty.
  *
  * NETWORK COMPUTING DEVICES AND  DIGITAL DISCLAIM ALL WARRANTIES WITH
- * REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF 
+ * REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF
  * MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL NETWORK COMPUTING DEVICES
- * OR DIGITAL BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES 
- * OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, 
- * WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, 
- * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS 
+ * OR DIGITAL BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES
+ * OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
+ * WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
+ * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
  * SOFTWARE.
  */
 
@@ -58,18 +58,22 @@ in this Software without prior written authorization from The Open Group.
 #endif
 #include <stdio.h>
 #include "FSlibint.h"
+#include <X11/Xtrans/Xtransint.h>
 #include <X11/Xos.h>
 
 static void _EatData32 ( FSServer *svr, unsigned long n );
-static char * _SysErrorMsg ( int n );
+static const char * _SysErrorMsg ( int n );
 
 /* check for both EAGAIN and EWOULDBLOCK, because some supposedly POSIX
  * systems are broken and return EWOULDBLOCK when they should return EAGAIN
+ *
+ * Solaris defines EWOULDBLOCK to be EAGAIN, so don't need to check twice
+ * for it.
  */
 #ifdef WIN32
 #define ETEST() (WSAGetLastError() == WSAEWOULDBLOCK)
 #else
-#if defined(EAGAIN) && defined(EWOULDBLOCK)
+#if defined(EAGAIN) && defined(EWOULDBLOCK) && (EAGAIN != EWOULDBLOCK)
 #define ETEST() (errno == EAGAIN || errno == EWOULDBLOCK)
 #else
 #ifdef EAGAIN
@@ -83,11 +87,7 @@ static char * _SysErrorMsg ( int n );
 #define ECHECK(err) (WSAGetLastError() == err)
 #define ESET(val) WSASetLastError(val)
 #else
-#ifdef ISC
-#define ECHECK(err) ((errno == err) || ETEST())
-#else
 #define ECHECK(err) (errno == err)
-#endif
 #define ESET(val) errno = val
 #endif
 
@@ -127,7 +127,7 @@ static fsReq _dummy_request = {
  * action is taken.  This routine correctly handles incremental writes.
  * This routine may have to be reworked if int < long.
  */
-void 
+void
 _FSFlush(register FSServer *svr)
 {
     register long size,
@@ -151,11 +151,6 @@ _FSFlush(register FSServer *svr)
 	    bufindex += write_stat;
 	} else if (ETEST()) {
 	    _FSWaitForWritable(svr);
-#ifdef SUNSYSV
-	} else if (ECHECK(0)) {
-	    _FSWaitForWritable(svr);
-#endif
-
 #ifdef EMSGSIZE
 	} else if (ECHECK(EMSGSIZE)) {
 	    if (todo > 1)
@@ -172,46 +167,10 @@ _FSFlush(register FSServer *svr)
     svr->last_req = (char *) &_dummy_request;
 }
 
-int
-_FSEventsQueued(
-    register FSServer	*svr,
-    int			 mode)
-{
-    register BytesReadable_t len;
-    BytesReadable_t pend;
-    char        buf[BUFSIZE];
-    register fsReply *rep;
-
-    if (mode == QueuedAfterFlush) {
-	_FSFlush(svr);
-	if (svr->qlen)
-	    return (svr->qlen);
-    }
-    if (_FSTransBytesReadable(svr->trans_conn, &pend) < 0)
-	(*_FSIOErrorFunction) (svr);
-    if ((len = pend) < SIZEOF(fsReply))
-	return (svr->qlen);	/* _FSFlush can enqueue events */
-    else if (len > BUFSIZE)
-	len = BUFSIZE;
-    len /= SIZEOF(fsReply);
-    pend = len * SIZEOF(fsReply);
-    _FSRead(svr, buf, (long) pend);
-
-    /* no space between comma and type or else macro will die */
-    STARTITERATE(rep, fsReply, buf, (len > 0), len--) {
-	if (rep->generic.type == FS_Error)
-	    _FSError(svr, (fsError *) rep);
-	else			/* must be an event packet */
-	    _FSEnq(svr, (fsEvent *) rep);
-    }
-    ENDITERATE
-	return (svr->qlen);
-}
-
 /* _FSReadEvents - Flush the output queue,
  * then read as many events as possible (but at least 1) and enqueue them
  */
-void 
+void
 _FSReadEvents(register FSServer *svr)
 {
     char        buf[BUFSIZE];
@@ -268,16 +227,13 @@ _FSReadEvents(register FSServer *svr)
  * _FSRead - Read bytes from the socket taking into account incomplete
  * reads.  This routine may have to be reworked if int < long.
  */
-void 
+void
 _FSRead(
     register FSServer	*svr,
     register char	*data,
     register long	 size)
 {
     register long bytes_read;
-#if defined(SVR4) && defined(i386)
-    int	num_failed_reads = 0;
-#endif
 
     if (size == 0)
 	return;
@@ -293,27 +249,11 @@ _FSRead(
 	if (bytes_read > 0) {
 	    size -= bytes_read;
 	    data += bytes_read;
-#if defined(SVR4) && defined(i386)
-	    num_failed_reads = 0;
-#endif
 	}
 	else if (ETEST()) {
 	    _FSWaitForReadable(svr);
-#if defined(SVR4) && defined(i386)
-	    num_failed_reads++;
-	    if (num_failed_reads > 1) {
-		ESET(EPIPE);
-		(*_FSIOErrorFunction) (svr);
-	    }
-#endif
 	    ESET(0);
 	}
-#ifdef SUNSYSV
-	else if (ECHECK(0)) {
-	    _FSWaitForReadable(svr);
-	}
-#endif
-
 	else if (bytes_read == 0) {
 	    /* Read failed because of end of file! */
 	    ESET(EPIPE);
@@ -322,152 +262,17 @@ _FSRead(
 	    /* If it's a system call interrupt, it's not an error. */
 	    if (!ECHECK(EINTR))
 		(*_FSIOErrorFunction) (svr);
-#if defined(SVR4) && defined(i386)
-	    else
-		num_failed_reads = 0;
-#endif
 	}
     }
 }
 
-#ifdef WORD64
-/*
- * XXX This is a *really* stupid way of doing this....
- */
-
-#define PACKBUFFERSIZE 4096
-
-
-/*
- * _FSRead32 - Read bytes from the socket unpacking each 32 bits
- *            into a long (64 bits on a CRAY computer).
- *
- */
-static void 
-_doFSRead32(
-    register FSServer	*svr,
-    register long	*data,
-    register long	 size,
-    register char	*packbuffer)
-{
-    long       *lpack,
-               *lp;
-    long        mask32 = 0x00000000ffffffff;
-    long        maskw,
-                nwords,
-                i,
-                bits;
-
-    _FSReadPad(svr, packbuffer, size);
-
-    lp = data;
-    lpack = (long *) packbuffer;
-    nwords = size >> 2;
-    bits = 32;
-
-    for (i = 0; i < nwords; i++) {
-	maskw = mask32 << bits;
-	*lp++ = (*lpack & maskw) >> bits;
-	bits = bits ^ 32;
-	if (bits) {
-	    lpack++;
-	}
-    }
-}
-
-void
-_FSRead32(
-    FSServer	*svr,
-    long	*data,
-    long	 len)
-{
-    char        packbuffer[PACKBUFFERSIZE];
-    unsigned    nwords = (PACKBUFFERSIZE >> 2);	/* bytes to CARD32 */
-
-    for (; len > nwords; len -= nwords, data += nwords) {
-	_doFSRead32(svr, data, nwords, packbuffer);
-    }
-    _doFSRead32(svr, data, len, packbuffer);
-}
-
-
-
-/*
- * _FSRead16 - Read bytes from the socket unpacking each 16 bits
- *            into a long (64 bits on a CRAY computer).
- *
- */
-static void 
-_doFSRead16(
-    register FSServer	*svr,
-    register short	*data,
-    register long	 size,
-    char		*packbuffer)
-{
-    long       *lpack,
-               *lp;
-    long        mask16 = 0x000000000000ffff;
-    long        maskw,
-                nwords,
-                i,
-                bits;
-
-    _FSRead(svr, packbuffer, size);	/* don't do a padded read... */
-
-    lp = (long *) data;
-    lpack = (long *) packbuffer;
-    nwords = size >> 1;		/* number of 16 bit words to be unpacked */
-    bits = 48;
-    for (i = 0; i < nwords; i++) {
-	maskw = mask16 << bits;
-	*lp++ = (*lpack & maskw) >> bits;
-	bits -= 16;
-	if (bits < 0) {
-	    lpack++;
-	    bits = 48;
-	}
-    }
-}
-
-void 
-_FSRead16(
-    FSServer	*svr,
-    short	*data,
-    long	 len)
-{
-    char        packbuffer[PACKBUFFERSIZE];
-    unsigned    nwords = (PACKBUFFERSIZE >> 1);	/* bytes to CARD16 */
-
-    for (; len > nwords; len -= nwords, data += nwords) {
-	_doFSRead16(svr, data, nwords, packbuffer);
-    }
-    _doFSRead16(svr, data, len, packbuffer);
-}
-
-void 
-_FSRead16Pad(
-    FSServer	*svr,
-    short	*data,
-    long	 size)
-{
-    int         slop = (size & 3);
-    short       slopbuf[3];
-
-    _FSRead16(svr, data, size);
-    if (slop > 0) {
-	_FSRead16(svr, slopbuf, 4 - slop);
-    }
-}
-
-#endif				/* WORD64 */
-
 
 /*
  * _FSReadPad - Read bytes from the socket taking into account incomplete
  * reads.  If the number of bytes is not 0 mod 32, read additional pad
  * bytes. This routine may have to be reworked if int < long.
  */
-void 
+void
 _FSReadPad(
     register FSServer	*svr,
     register char	*data,
@@ -479,7 +284,7 @@ _FSReadPad(
 
     if (size == 0)
 	return;
-    iov[0].iov_len = (int) size;
+    iov[0].iov_len = size;
     iov[0].iov_base = data;
     /*
      * The following hack is used to provide 32 bit long-word aligned padding.
@@ -491,7 +296,7 @@ _FSReadPad(
     size += iov[1].iov_len;
 
     ESET(0);
-    while ((bytes_read = _FSTransReadv(svr->trans_conn, iov, 2)) != size) {
+    while ((bytes_read = readv(svr->trans_conn->fd, iov, 2)) != size) {
 
 	if (bytes_read > 0) {
 	    size -= bytes_read;
@@ -510,12 +315,6 @@ _FSReadPad(
 	    _FSWaitForReadable(svr);
 	    ESET(0);
 	}
-#ifdef SUNSYSV
-	else if (ECHECK(0)) {
-	    _FSWaitForReadable(svr);
-	}
-#endif
-
 	else if (bytes_read == 0) {
 	    /* Read failed because of end of file! */
 	    ESET(EPIPE);
@@ -533,10 +332,10 @@ _FSReadPad(
  * transmission is used, if size is not 0 mod 4, extra bytes are transmitted.
  * This routine may have to be reworked if int < long;
  */
-void 
+void
 _FSSend(
     register FSServer	*svr,
-    char		*data,
+    const char		*data,
     register long	 size)
 {
     struct iovec iov[3];
@@ -550,10 +349,10 @@ _FSSend(
 
     /*
      * There are 3 pieces that may need to be written out:
-     * 
+     *
      * o  whatever is in the display buffer o  the data passed in by the user o
      * any padding needed to 32bit align the whole mess
-     * 
+     *
      * This loop looks at all 3 pieces each time through.  It uses skip to figure
      * out whether or not a given piece is needed.
      */
@@ -567,12 +366,12 @@ _FSSend(
 	 * You could be very general here and have "in" and "out" iovecs and
 	 * write a loop without using a macro, but what the heck.  This
 	 * translates to:
-	 * 
+	 *
 	 * how much of this piece is new? if more new then we are trying this
 	 * time, clamp if nothing new then bump down amount already written,
 	 * for next piece else put new stuff in iovec, will need all of next
 	 * piece
-	 * 
+	 *
 	 * Note that todo had better be at least 1 or else we'll end up writing 0
 	 * iovecs.
 	 */
@@ -591,7 +390,7 @@ _FSSend(
 	    }
 
 	InsertIOV(svr->buffer, svrbufsize)
-	InsertIOV(data, size)
+	InsertIOV((char *)data, size)
 	InsertIOV(pad, padsize)
 
 	ESET(0);
@@ -601,11 +400,6 @@ _FSSend(
 	    todo = total;
 	} else if (ETEST()) {
 		_FSWaitForWritable(svr);
-#ifdef SUNSYSV
-	} else if (ECHECK(0)) {
-	    _FSWaitForWritable(svr);
-#endif
-
 #ifdef EMSGSIZE
 	} else if (ECHECK(EMSGSIZE)) {
 	    if (todo > 1)
@@ -625,7 +419,7 @@ _FSSend(
 #ifdef undef
 /*
  * _FSAllocID - normal resource ID allocation routine.  A client
- * can roll his own and instatantiate it if he wants, but must
+ * can roll their own and instantiate it if they want, but must
  * follow the rules.
  */
 FSID
@@ -683,7 +477,7 @@ _FSReply(
     register fsReply	*rep,
     int			 extra,	 /* number of 32-bit words expected after the
 				  * reply */
-    Bool		 discard)/* should I discard data followind "extra"
+    Bool		 discard)/* should I discard data following "extra"
 				  * words? */
 {
     /*
@@ -748,7 +542,8 @@ _FSReply(
 		unsigned long serial;
 		long        err_data;
 
-		err = *(fsError *) rep;
+		/* copy in the part we already read off the wire */
+		memcpy(&err, rep, SIZEOF(fsReply));
 		/* read the rest of the error */
 		_FSRead(svr, (char *) &err + SIZEOF(fsReply),
 			(long) (SIZEOF(fsError) - SIZEOF(fsReply)));
@@ -835,7 +630,7 @@ _EatData32(
  * note that no squishing of move events in V11, since there
  * is pointer motion hints....
  */
-void 
+void
 _FSEnq(
     register FSServer	*svr,
     register fsEvent	*event)
@@ -846,8 +641,7 @@ _FSEnq(
     if ((qelt = _FSqfree) != NULL) {
 	/* If _FSqfree is non-NULL do this, else malloc a new one. */
 	_FSqfree = qelt->next;
-    } else if ((qelt =
-	     (_FSQEvent *) FSmalloc((unsigned) sizeof(_FSQEvent))) == NULL) {
+    } else if ((qelt = FSmalloc(sizeof(_FSQEvent))) == NULL) {
 	/* Malloc call failed! */
 	ESET(ENOMEM);
 	(*_FSIOErrorFunction) (svr);
@@ -870,7 +664,7 @@ _FSEnq(
 }
 
 /*
- * EventToWire in seperate file in that often not needed.
+ * EventToWire in separate file that is often not needed.
  */
 
 /*ARGSUSED*/
@@ -909,36 +703,7 @@ _FSUnknownNativeEvent(
     return (0);
 }
 
-/*
- * reformat a wire event into an FSEvent structure of the right type.
- */
-Bool
-_FSWireToEvent(
-    register FSServer	*svr,	/* pointer to display structure */
-    register FSEvent	*re,	/* pointer to where event should be
-				 * reformatted */
-    register fsEvent	*event)	/* wire protocol event */
-{
-
-    re->type = event->type & 0x7f;
-    ((FSAnyEvent *) re)->serial = _FSSetLastRequestRead(svr,
-						   (fsGenericReply *) event);
-    ((FSAnyEvent *) re)->send_event = ((event->type & 0x80) != 0);
-    ((FSAnyEvent *) re)->server = svr;
-
-    /*
-     * Ignore the leading bit of the event type since it is set when a client
-     * sends an event rather than the server.
-     */
-
-    switch (event->type & 0177) {
-    default:
-	return (_FSUnknownWireEvent(svr, re, event));
-    }
-}
-
-
-static char *
+static const char *
 _SysErrorMsg(int n)
 {
     char       *s = strerror(n);
@@ -946,6 +711,11 @@ _SysErrorMsg(int n)
     return (s ? s : "no such error");
 }
 
+#ifdef __SUNPRO_C
+/* prevent "Function has no return statement" error for _FSDefaultIOError */
+#pragma does_not_return(exit)
+#endif
+
 /*
  * _FSDefaultIOError - Default fatal system error reporting routine.  Called
  * when an X internal system error is encountered.
@@ -1004,6 +774,11 @@ _FSError(
     /* NOTREACHED */
 }
 
+#ifdef __clang__
+#pragma clang diagnostic push
+#pragma clang diagnostic ignored "-Wformat-nonliteral" // We know better
+#endif
+
 int
 _FSPrintDefaultError(
     FSServer		*svr,
@@ -1013,36 +788,40 @@ _FSPrintDefaultError(
     char        buffer[BUFSIZ];
     char        mesg[BUFSIZ];
     char        number[32];
-    char       *mtype = "FSlibMessage";
+    const char *mtype = "FSlibMessage";
     register _FSExtension *ext = (_FSExtension *) NULL;
 
     (void) FSGetErrorText(svr, event->error_code, buffer, BUFSIZ);
-    (void) FSGetErrorDatabaseText(svr, mtype, "FSError", "FS Error", mesg, 
+    (void) FSGetErrorDatabaseText(svr, mtype, "FSError", "FS Error", mesg,
 				  BUFSIZ);
     (void) fprintf(fp, "%s:  %s\n  ", mesg, buffer);
-    (void) FSGetErrorDatabaseText(svr, mtype, "MajorCode", 
+    (void) FSGetErrorDatabaseText(svr, mtype, "MajorCode",
 				  "Request Major code %d", mesg, BUFSIZ);
     (void) fprintf(fp, mesg, event->request_code);
     if (event->request_code < 128) {
 	snprintf(number, sizeof(number), "%d", event->request_code);
-	(void) FSGetErrorDatabaseText(svr, "FSRequest", number, "", buffer, 
+	(void) FSGetErrorDatabaseText(svr, "FSRequest", number, "", buffer,
 				      BUFSIZ);
     } else {
 	for (ext = svr->ext_procs;
 		ext && (ext->codes.major_opcode != event->request_code);
 		ext = ext->next);
 	if (ext)
+#ifdef HAVE_STRLCPY
+	    strlcpy(buffer, ext->name, sizeof(buffer));
+#else
 	    strcpy(buffer, ext->name);
+#endif
 	else
 	    buffer[0] = '\0';
     }
     (void) fprintf(fp, " (%s)\n  ", buffer);
-    (void) FSGetErrorDatabaseText(svr, mtype, "MinorCode", 
+    (void) FSGetErrorDatabaseText(svr, mtype, "MinorCode",
 				  "Request Minor code %d", mesg, BUFSIZ);
     (void) fprintf(fp, mesg, event->minor_code);
     if (ext) {
 	snprintf(mesg, sizeof(mesg), "%s.%d", ext->name, event->minor_code);
-	(void) FSGetErrorDatabaseText(svr, "FSRequest", mesg, "", buffer, 
+	(void) FSGetErrorDatabaseText(svr, "FSRequest", mesg, "", buffer,
 				      BUFSIZ);
 	(void) fprintf(fp, " (%s)", buffer);
     }
@@ -1055,13 +834,17 @@ _FSPrintDefaultError(
 				  mesg, BUFSIZ);
     (void) fprintf(fp, mesg, event->serial);
     fputs("\n  ", fp);
-    (void) FSGetErrorDatabaseText(svr, mtype, "CurrentSerial", 
+    (void) FSGetErrorDatabaseText(svr, mtype, "CurrentSerial",
 				  "Current Serial #%d", mesg, BUFSIZ);
     (void) fprintf(fp, mesg, svr->request);
     fputs("\n", fp);
     return 1;
 }
 
+#ifdef __clang__
+#pragma clang diagnostic pop
+#endif
+
 int
 _FSDefaultError(
     FSServer		*svr,
@@ -1077,26 +860,7 @@ _FSDefaultError(
 FSIOErrorHandler _FSIOErrorFunction = _FSDefaultIOError;
 FSErrorHandler _FSErrorFunction = _FSDefaultError;
 
-/*
- * This routine can be used to (cheaply) get some memory within a single
- * Xlib routine for scratch space.  It is reallocated from the same place
- * each time, unless the library needs a large scratch space.
- */
-char       *
-_FSAllocScratch(
-    register FSServer	*svr,
-    unsigned long	 nbytes)
-{
-    if (nbytes > svr->scratch_length) {
-	if (svr->scratch_buffer != NULL)
-	    FSfree(svr->scratch_buffer);
-	return (svr->scratch_length = nbytes,
-		svr->scratch_buffer = FSmalloc((unsigned) nbytes));
-    }
-    return (svr->scratch_buffer);
-}
-
-int 
+int
 FSFree(char *data)
 {
     FSfree(data);
@@ -1127,138 +891,6 @@ Data(
 #endif				/* DataRoutineIsProcedure */
 
 
-#ifdef WORD64
-/*
- * XXX This is a *really* stupid way of doing this.  It should just use
- * svr->bufptr directly, taking into account where in the word it is.
- */
-
-/*
- * Data16 - Place 16 bit data in the buffer.
- *
- * "svr" is a pointer to a FSServer.
- * "data" is a pointer to the data.
- * "len" is the length in bytes of the data.
- */
-
-static void
-doData16(
-    register FSServer	*svr,
-    short		 *data,
-    unsigned		 len,
-    char		*packbuffer)
-{
-    long       *lp,
-               *lpack;
-    long        i,
-                nwords,
-                bits;
-    long        mask16 = 0x000000000000ffff;
-
-    lp = (long *) data;
-    lpack = (long *) packbuffer;
-    *lpack = 0;
-
-/*  nwords is the number of 16 bit values to be packed,
- *  the low order 16 bits of each word will be packed
- *  into 64 bit words
- */
-    nwords = len >> 1;
-    bits = 48;
-
-    for (i = 0; i < nwords; i++) {
-	*lpack ^= (*lp & mask16) << bits;
-	bits -= 16;
-	lp++;
-	if (bits < 0) {
-	    lpack++;
-	    *lpack = 0;
-	    bits = 48;
-	}
-    }
-    Data(svr, packbuffer, len);
-}
-
-void
-Data16(svr, data, len)
-    FSServer	*svr,
-    short	*data,
-    unsigned	 len)
-{
-    char        packbuffer[PACKBUFFERSIZE];
-    unsigned    nwords = (PACKBUFFERSIZE >> 1);	/* bytes to CARD16 */
-
-    for (; len > nwords; len -= nwords, data += nwords) {
-	doData16(svr, data, nwords, packbuffer);
-    }
-    doData16(svr, data, len, packbuffer);
-}
-
-/*
- * Data32 - Place 32 bit data in the buffer.
- *
- * "svr" is a pointer to a FSServer.
- * "data" is a pointer to the data.
- * "len" is the length in bytes of the data.
- */
-
-static
-doData32(
-    register FSServer	*svr,
-    long		*data,
-    unsigned		 len,
-    char		*packbuffer)
-{
-    long       *lp,
-               *lpack;
-    long        i,
-                bits,
-                nwords;
-    long        mask32 = 0x00000000ffffffff;
-
-    lpack = (long *) packbuffer;
-    lp = data;
-
-    *lpack = 0;
-
-/*  nwords is the number of 32 bit values to be packed
- *  the low order 32 bits of each word will be packed
- *  into 64 bit words
- */
-    nwords = len >> 2;
-    bits = 32;
-
-    for (i = 0; i < nwords; i++) {
-	*lpack ^= (*lp & mask32) << bits;
-	bits = bits ^ 32;
-	lp++;
-	if (bits) {
-	    lpack++;
-	    *lpack = 0;
-	}
-    }
-    Data(svr, packbuffer, len);
-}
-
-void
-Data32(
-    FSServer	*svr,
-    short	*data,
-    unsigned	 len)
-{
-    char        packbuffer[PACKBUFFERSIZE];
-    unsigned    nwords = (PACKBUFFERSIZE >> 2);	/* bytes to CARD32 */
-
-    for (; len > nwords; len -= nwords, data += nwords) {
-	doData32(svr, data, nwords, packbuffer);
-    }
-    doData32(svr, data, len, packbuffer);
-}
-
-#endif				/* WORD64 */
-
-
-
 /*
  * _FSFreeQ - free the queue of events, called by XCloseServer when there are
  * no more displays left on the display list
@@ -1279,57 +911,6 @@ _FSFreeQ(void)
     return;
 }
 
-#ifdef _POSIX_SOURCE                     /* stupid makedepend [need if] */
-#ifndef __QNX__ /* QNX's uname nodename entry is not same as tcpip hostname */
-#define NEED_UTSNAME
-#endif
-#endif
-#ifdef hpux
-#define NEED_UTSNAME
-#endif
-#ifdef SVR4
-#ifndef _SEQUENT_
-#define NEED_UTSNAME
-#endif
-#endif
-
-#ifdef NEED_UTSNAME
-#include <sys/utsname.h>
-#endif
-
-
-/*
- * _FSGetHostname - similar to gethostname but allows special processing.
- */
-int
-_FSGetHostname(
-    char	*buf,
-    int		 maxlen)
-{
-    int         len;
-
-#ifdef NEED_UTSNAME
-    /*
-     * same host name crock as in server and xinit.
-     */
-    struct utsname name;
-
-    uname(&name);
-    len = strlen(name.nodename);
-    if (len >= maxlen)
-	len = maxlen - 1;
-    strncpy(buf, name.nodename, len);
-    buf[len] = '\0';
-#else
-    buf[0] = '\0';
-    (void) gethostname(buf, maxlen);
-    buf[maxlen - 1] = '\0';
-    len = strlen(buf);
-#endif				/* NEED_UTSNAME */
-
-    return len;
-}
-
 #ifndef _FSANYSET
 /*
  * This is not always a macro.
